orion.Orion
===========

.. currentmodule:: orion

.. autoclass:: Orion

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
   
      ~Orion.__init__
      ~Orion.detect
      ~Orion.evaluate
      ~Orion.fit
      ~Orion.fit_detect
      ~Orion.load
      ~Orion.save
   
   

   
   
   .. rubric:: Attributes

   .. autosummary::
   
      ~Orion.DEFAULT_PIPELINE
      ~Orion.PIPELINES
      ~Orion.PIPELINES_DIR
   
   